<?php

class AdminController extends BaseController
{
    // ********** Admin Index page ********** //

    public function index()
    {
        return $this->home();
    }

    // ********** Home Admin page ********** //

    public function home()
    {
        $settings = Setting::first();
        $genres = Genre::orderBy('order_id')->get();
        $data = array(
            'genres' => $genres,
            'settings' => $settings
            );
        return View::make('admin.home', $data);
    }

    // ********** Home update method ********** //

    public function updateHome()
    {
        $input = Input::all();
        $genres = Genre::all();
        $settings = Setting::first();
        foreach ($genres as $i => $genre) {
            $genre->where('id', $i+1)->update(array('order_id' => $input[$i+1]));
        }
        $settings->country_code = htmlspecialchars($input['country_code']);
        $settings->save();

        $notification_text = Lang::get('words.update_home_success');

        return Redirect::to('admin/home')->with(array('toastMsg' => $notification_text, 'toastType' => 'showSuccessToast'));
    }

    // ********** Users Admin page ********** //

    public function users()
    {
        //Display 10 users at a time
        $users = User::orderBy('admin', 'DESC')->orderBy('created_at', 'DESC')->paginate(10);
        $settings = Setting::first();
        $data = array(
            'users' => $users,
            'settings' => $settings
            );

        return View::make('admin.users', $data);
    }

    // ********** Settings Admin page ********** //

    public function settings()
    {
        //Display settings for the application
        $settings = Setting::first();
        $data = array(
            'settings' => $settings,
            );

        return View::make('admin.settings', $data);
    }

    // ********** Settings Admin page ********** //

    public function social()
    {
        //Display settings for the application
        $settings = Setting::first();
        $data = array(
            'settings' => $settings,
            );

        return View::make('admin.social', $data);
    }

    // ********** Footer link pages ********** //

    public function pages()
    {
        $pages = Page::all();
        $settings = Setting::first();
        return View::make('admin.pages', array('pages' => $pages, 'settings' => $settings));
    }

    // ********** Pages update method ********** //

    public function updatePages()
    {
        $input = Input::all();
        $pages = Page::all();
        foreach ($pages as $page) {
            $page->description = $input[$page->title];
            $page->save();
        }
        $notification_text = Lang::get('words.update_pages_success');

        return Redirect::to('admin/pages')->with(array('toastMsg' => $notification_text, 'toastType' => 'showSuccessToast'));
    }

    // ********** Settings update method ********** //

    public function updateSettings()
    {
        $input = Input::all();
        $settings = Setting::first();

        $settings->website_name = htmlspecialchars($input['website_name']);
        $settings->website_title = htmlspecialchars($input['website_title']);
        $settings->website_keywords = htmlspecialchars($input['website_keywords']);
        $settings->website_description = htmlspecialchars($input['website_description']);

        $settings->theme_color = htmlspecialchars($input['theme_color']);
        $settings->player_color = htmlspecialchars($input['player_color']);

        $settings->recaptcha_site_key = htmlspecialchars($input['recaptcha_site_key']);
        $settings->recaptcha_secret_key = htmlspecialchars($input['recaptcha_secret_key']);

        $settings->soundcloud_id = htmlspecialchars($input['soundcloud_id']);
        $settings->youtube_key = htmlspecialchars($input['youtube_key']);

        $settings->per_page = stripslashes($input['per_page']);

        $settings->analytics = stripslashes($input['analytics']);

        $settings->auth_download = isset($input['auth_download']) ? 1 : 0;

        $settings->max_top = stripcslashes($input['max_top']);

        $settings->save();

        $notification_text = Lang::get('words.update_settings_success');
        $toastType = 'showSuccessToast';

        if (isset($input['website_logo'])) {
            $validation = Validator::make($input, array('website_logo' => 'mimes:jpeg,bmp,png'));
            if ($validation->passes()) {
                Helper::uploadImage(Input::file('website_logo'));
            } else {
                $notification_text = $validation->messages()->all()[0];
                $toastType = 'showErrorToast';
            }
        }

        return Redirect::to('admin/settings')->with(array('toastMsg' => $notification_text, 'toastType' => $toastType));
    }

    // ********** Social Settings update method ********** //

    public function updateSocial()
    {
        $input = Input::all();
        $settings = Setting::first();


        $settings->fb_key = htmlspecialchars($input['fb_key']);
        $settings->fb_secret_key = htmlspecialchars($input['fb_secret_key']);
        $settings->facebook_page_id = htmlspecialchars($input['facebook_page_id']);

        $settings->twitter_key = htmlspecialchars($input['twitter_key']);
        $settings->twitter_secret_key = htmlspecialchars($input['twitter_secret_key']);

        $settings->google_key = htmlspecialchars($input['google_key']);
        $settings->google_secret_key = htmlspecialchars($input['google_secret_key']);
        $settings->google_page_id = htmlspecialchars($input['google_page_id']);

        $settings->twitter_page_id = htmlspecialchars($input['twitter_page_id']);


        $settings->save();

        $notification_text = Lang::get('words.update_social_success');
        $toastType = 'showSuccessToast';

        return Redirect::to('admin/social')->with(array('toastMsg' => $notification_text, 'toastType' => $toastType));
    }

    // ********** Advertisement page ********** //

    public function ads()
    {
        $ads = Ads::first();
        $settings = Setting::first();
        $data = array('ads' => $ads, 'settings' => $settings);

        return View::make('admin.ads', $data);
    }

    // ********** Advertisement update method ********** //

    public function updateAds()
    {
        $input = Input::all();
        $ads = Ads::first();
        $ads->ajax_loading = isset($input['ajax_loading']) ? 1 : 0;
        $ads->box = stripslashes($input['box']);
        $ads->banner_large = stripslashes($input['banner_large']);
        $ads->mobile = stripslashes($input['mobile']);
        $ads->skyscrapper = stripslashes($input['skyscrapper']);
        $ads->adfly_ad = stripslashes($input['adfly_ad']);
        $ads->ads_per = stripslashes($input['ads_per']);
        $ads->ad_center = stripslashes($input['ad_center']);
        $ads->save();

        $notification_text = Lang::get('words.update_ads_success');

        return Redirect::to('admin/adcode')->with(array('toastMsg' => $notification_text, 'toastType' => 'showSuccessToast'));
    }

    // ********** Deactivate User method ********** //

    public function deactivateUser($id)
    {
        $user = User::find($id);
        if ($user->admin) {
            return Redirect::to('admin/users')->with(array('toastMsg' => Lang::get('words.cant_deactivate_admin'), 'toastType' => 'showErrorToast'));
        }
        $user->active = 0;
        $user->save();

        return Redirect::to('admin/users')->with(array('toastMsg' => Lang::get('words.deactivate_user'), 'toastType' => 'showSuccessToast'));
    }

    // ********** Activate User method ********** //

    public function activateUser($id)
    {
        $user = User::find($id);
        $user->active = 1;
        $user->save();

        return Redirect::to('admin/users')->with(array('toastMsg' => Lang::get('words.activate_user'), 'toastType' => 'showSuccessToast'));
    }

    // ********** Toggle Genre status method ********** //

    public function toggleGenre()
    {
        $input = Input::all();
        $genre_id = $input['genre_id'];
        $genre = Genre::where('id', $genre_id)->first();
        $status = $genre->is_visible ? 0 : 1;
        $genre->is_visible = $status;
        $genre->save();
        return 'ok';
    }
}
