<?php
class IndexController extends BaseController
{

    // ********** Index Controller //

    public function index()
    {
        try {
            // Try if settings for the application exists
            $settings = Setting::first();
            if ($settings) {
                // If settings exists, the application is most likely installed
                // Please remove database table manually to re-install
                $search = Input::get('search');
                if (isset($search)) {
                    // If search parameter is set
                    // Redirect to search results route
                    return Redirect::to('search/'.Helper::slugify($search));
                } else {
                    // Else display top songs page
                    return App::make('AppleAPIController')->getSongs();
                }
            } else {
                // Throw new exception
                throw new Exception('Throw Settings not found Exception');
            }
        } catch (Exception $e) {
            // Take user to install page
            return View::make('install');
        }
    }

    // ********** Install Route ********** //

    public function install()
    {
        try {
            // Try if settings for the application exists
            $settings = Setting::first();
            if ($settings) {
                // If settings exists, the application is most likely installed
                // Please remove database table manually to re-install
                return Redirect::to('/');
            } else {
                // Throw new exception
                throw new Exception('Throw Settings not found Exception');
            }
        } catch (Exception $e) {
            // Take user to install page
            return View::make('install');
        }
    }

    // ********** Write Database config file ********** //

    public function writeDBConfigFile()
    {
        if (Request::ajax()) {
            try {
                // Try if settings for the application exists
                $settings = Setting::first();
                if ($settings) {
                    // If settings exists, the application is most likely installed
                    // Please remove database table manually to re-install
                    return Redirect::to('/');
                } else {
                    // Throw new exception
                    throw new Exception('Throw Settings not found Exception');
                }
            } catch (Exception $e) {
                // Attempt to write a new config file
                $db_host = $_POST['database_host'];
                $db_name = $_POST['database_name'];
                $db_user = $_POST['database_user'];
                $db_password = $_POST['database_password'];

                // Location of config file
                $file = '../app/config/config.php';
                $config_string = "<?php
                                return array(
                                        'db_host' => '$db_host',
                                        'db_name' => '$db_name',
                                        'db_user' => '$db_user',
                                        'db_password' => '$db_password'
                                    );";
                // create a config file conataining database details
                $new_file = file_put_contents($file, $config_string);
                if ($new_file !== false) {
                    // Return true if no errors
                    echo 1;
                } else {
                    // Return false if there are any errors
                    echo 0;
                }
            }
        } else {
            // Return false if ajax requests fails
            echo 0;
        }
    }

    // ********** Is Database Connects ********** //

    public function isDBConnect()
    {
        if (Request::ajax()) {
            //Attempt to connect to the database
            try {
                // Get post fields from form
                $db_host = $_POST['database_host'];
                $db_name = $_POST['database_name'];
                $db_user = $_POST['database_user'];
                $db_password = $_POST['database_password'];

                //If all fields are NOT empty
                if (!empty($db_host) && !empty($db_name) && !empty($db_user)) {
                    // Create a new database connection
                    $con = @mysqli_connect($db_host, $db_user, $db_password, $db_name);
                    if (mysqli_connect_errno($con)) {
                        // Return false if error occurs
                        echo 0;
                    } else {
                        // Return true if no error occurs
                        echo 1;
                    }
                } else {
                    // Return true if no error occurs
                    echo 0;
                }
            } catch (Exception $e) {
                // Return false if failed to connect to the database
                echo 0;
            }
        } else {
            // Return false if ajax requests fails
            echo 0;
        }
    }

    // ********** Create Database ********** //

    public function createDB()
    {
        if (Request::ajax()) {
            try {
                // Try if settings for the application exists
                $settings = Setting::first();
                if ($settings) {
                    // If settings exists, the application is most likely installed
                    // Please remove database table manually to re-install
                    return Redirect::to('/');
                } else {
                    // Throw new exception
                    throw new Exception('Throw Settings not found Exception');
                }
            } catch (Exception $e) {
                try {
                    // Try to migrate the database

                    $db_host = $_POST['database_host'];
                    $db_name = $_POST['database_name'];
                    $db_user = $_POST['database_user'];
                    $db_password = $_POST['database_password'];

                    // Temporarily attempt to connect to database
                    Config::set('database.connections.mysql.host', $db_host);
                    Config::set('database.connections.mysql.database', $db_name);
                    Config::set('database.connections.mysql.username', $db_user);
                    Config::set('database.connections.mysql.password', $db_password);

                    //Migrate the database tables
                    Artisan::call('migrate', ['--quiet' => true, '--force' => true]);
                    
                    //Seed database tables with default settings.
                    Artisan::call('db:seed', array('--quiet' => true, '--force' => true, '--class' => 'SettingsTableSeeder'));
                    Artisan::call('db:seed', array('--quiet' => true, '--force' => true, '--class' => 'AdsTableSeeder'));
                    Artisan::call('db:seed', array('--quiet' => true, '--force' => true, '--class' => 'PagesTableSeeder'));
                    Artisan::call('db:seed', array('--quiet' => true, '--force' => true, '--class' => 'GenresTableSeeder'));
                    echo 1;
                } catch (Exception $e) {
                    // Return false if Exception is thrown
                    echo 0;
                }
            }
        } else {
            // Return false if ajax requests fails
            echo 0;
        }
    }

    // ********** Create admin ********** //

    public function createAdmin()
    {
        if (Request::ajax()) {
            try {
                // Attempt to check if admin already exists
                $user = User::first();
                if ($user) {
                    // If admin exists redirect to Index page
                    return Redirect::to('/');
                } else {
                    // Throw an exception
                    throw new Exception('User not found Exception occurs');
                }
            } catch (Exception $e) {
                //create an admin user
                $admin_username = Input::get('admin_username');
                $admin_email = Input::get('admin_email');
                $admin_password = Hash::make(Input::get('admin_password'));
                
                // Create a new admin user
                $user = new User();
                $user->username = $admin_username;
                $user->email = $admin_email;
                $user->password = $admin_password;
                $user->admin = 1;
                $user->active = 1;
                $new_user = $user->save();
                if ($new_user) {
                    // Attempt to login the new user
                    Auth::attempt(array('email' => Input::get('admin_email'), 'password' => Input::get('admin_password')));
                    // Return true if admin created
                    echo 1;
                } else {
                    // Return false if fails to create admin
                    echo 0;
                }
            }
        } else {
            // Return false if ajax requests fails
            echo 0;
        }
    }

    // Update Application

    public function update()
    {
        $updated = $this->updateV3();

        if ($updated) {
            return Redirect::to('/')->with(array('toastMsg' => 'Application Successfully Updated', 'toastType' => 'showSuccessToast'));
        } else {
            return Redirect::to('/');
        }
    }

    private function updateV3()
    {
        Schema::dropIfExists('home');
        if (!Schema::hasTable('genres')) {
            Schema::create(
                'genres',
                function ($table) {
                    $table->increments('id');
                    $table->string('name', 50);
                    $table->integer('genre_id');
                    $table->integer('order_id');
                    $table->boolean('is_visible')->default(1);
                }
                );
            Artisan::call('db:seed', array('--quiet' => true, '--force' => true, '--class' => 'GenresTableSeeder'));
        }

        if(Schema::hasTable('settings')) {
            Schema::table('settings', function($table)
            {
                $table->string('youtube_key')->default('');
                $table->boolean('auth_download')->default(0);
                $table->integer('max_top')->default(28);
                $table->string('country_code')->default('in');
            });
        }

        if(Schema::hasTable('ads')) {
            Schema::table('ads', function($table)
            {
                $table->boolean('ajax_loading')->default(1);
            });
        }

        return true;
    }
}
