<?php

class UserController extends BaseController
{
    /**
     * User Repository
     *
     * @var User
     */
    protected $user;

    public function __construct(User $user)
    {
        $this->user = $user;
    }

    public static $rules = array(
        'username' => 'required|unique:users|alpha_dash|between:5,15',
        'email' => 'required|email|unique:users',
        'password' => 'required|alpha_dash|between:6,12|confirmed',
        'password_confirmation' => 'required|alpha_dash|between:6,12',
        'g-recaptcha-response' => 'required|recaptcha',
    );

    // *********** USER LOGIN ********** //

    public function login()
    {
        $email_login = array(
            'email' => Input::get('email'),
            'password' => Input::get('password'),
            'active' => 1,
        );

        $username_login = array(
            'username' => Input::get('email'),
            'password' => Input::get('password'),
            'active' => 1,
        );

        $remember = Input::get('remember') == 'on' ? true : false;

        if (Auth::attempt($email_login, $remember) || Auth::attempt($username_login, $remember)) {
            return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.login_success'), 'toastType' => 'showSuccessToast'));
        } else {
            return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.login_error'), 'toastType' => 'showErrorToast'));
        }
    }

    // *********** FACEBOOK OAUTH SIGNIN/SIGNUP ********** //

    public function loginWithFacebook()
    {
        $settings = Setting::first();
        $code = Input::get('code');

        $fb = ArtDarekOAuth::consumer('Facebook');
        
        if (!empty($code)) {
            // This was a callback request from facebook, get the token
            $token = $fb->requestAccessToken($code);

            // Send a request with it
            $result = json_decode($fb->request('/me'), true);
            
            $oauth_userid = $result['id'];
            $oauth_email = $result['email'];
            $oauth_username = explode('@', $oauth_email);
            $oauth_username = $oauth_username[0];
            
            if (isset($oauth_userid) && isset($oauth_username) && isset($oauth_email)) {
                $fb_auth = Oauth::where('oauth_userid', '=', $oauth_userid)->where('service', '=', 'facebook')->first();
                if (isset($fb_auth->id)) {
                    $user = $this->user->find($fb_auth->user_id);
                } else {
                    // Execute Add or Login Oauth User
                    $user = $this->user->where('email', '=', $oauth_email)->first();
                    if (!isset($user->id)) {
                        $username = $this->createUsernameIfExists($oauth_username);
                        $email = $oauth_email;
                        $password = Hash::make(Helper::slugify('', 12));

                        $user = $this->newUser($username, $email, $password, 1, null);
                        $new_oauth_user = new Oauth();
                        $new_oauth_user->user_id = $user->id;
                        $new_oauth_user->service = 'facebook';
                        $new_oauth_user->oauth_userid = $oauth_userid;
                        $new_oauth_user->save();
                    } else {
                        // Redirect and send error message that email already exists. Let them know that they can request to reset password if they do not remember
                        return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.oauth_email_used'), 'toastType' => 'showErrorToast'));
                    }
                }
                // Redirect to new User Login;
                Auth::login($user, true);
                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.facebook_success'), 'toastType' => 'showSuccessToast'));
            }

        } else {
            $url = $fb->getAuthorizationUri();
            // return to facebook login url
            return Redirect::to((string)$url);
        }
    }

    // *********** TWITTER OAUTH SIGNIN/SIGNUP ********** //

    public function loginWithTwitter()
    {
        $settings = Setting::first();

        // get data from input
        $token = Input::get('oauth_token');
        $verify = Input::get('oauth_verifier');

        // get twitter service
        $tw = ArtDarekOAuth::consumer('Twitter');

        // if code is provided get user data and sign in
        if (!empty($token) && !empty($verify)) {
            // This was a callback request from twitter, get the token
            $token = $tw->requestAccessToken($token, $verify);

            // Send a request with it
            $result = json_decode($tw->request('account/verify_credentials.json'), true);
            
            $oauth_userid = $result['id'];
            $oauth_username = Helper::slugify($result['screen_name']);
            $oauth_email = strtolower($result['screen_name']).'@twitter.com';

            if (isset($oauth_userid) && isset($oauth_username) && isset($oauth_email)) {
                $twitter_auth = Oauth::where('oauth_userid', '=', $oauth_userid)->where('service', '=', 'twitter')->first();

                if (isset($twitter_auth->id)) {
                    $user = $this->user->find($twitter_auth->user_id);
                } else {
                    // Execute Add or Login Oauth User
                    $user = $this->user->where('email', '=', $oauth_email)->first();

                    if (!isset($user->id)) {
                        $username = $this->createUsernameIfExists($oauth_username);
                        $email = $oauth_email;
                        $password = Hash::make(Helper::slugify('', 12));
                        $user = $this->newUser($username, $email, $password, 1, null);
                        $new_oauth_user = new Oauth();
                        $new_oauth_user->user_id = $user->id;
                        $new_oauth_user->service = 'twitter';
                        $new_oauth_user->oauth_userid = $oauth_userid;
                        $new_oauth_user->save();
                    } else {
                        // Redirect and send error message that email already exists. Let them know that they can request to reset password if they do not remember
                        return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.oauth_email_used'), 'toastType' => 'showErrorToast'));
                    }
                }
                // Redirect to new User Login;
                Auth::login($user, true);
                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.twitter_success'), 'toastType' => 'showSuccessToast'));
            
            }
        } else {
            // get request token
            $reqToken = $tw->requestRequestToken();
            // get Authorization Uri sending the request token
            $url = $tw->getAuthorizationUri(array('oauth_token' => $reqToken->getRequestToken()));

            //dd($url);
            return Redirect::to((string)$url);
        }
    }

    // *********** GOOGLE OAUTH SIGNIN/SIGNUP ********** //

    public function loginWithGoogle()
    {
        $settings = Setting::first();

        // get data from input
        $code = Input::get('code');

        // get google service
        $googleService = ArtDarekOAuth::consumer('Google');

        // if code is provided get user data and sign in
        if (!empty($code)) {
            
            // This was a callback request from google, get the token
            $token = $googleService->requestAccessToken($code);

            // Send a request with it
            $result = json_decode($googleService->request('https://www.googleapis.com/oauth2/v1/userinfo'), true);

            $oauth_userid = $result['id'];
            $oauth_username = Helper::slugify($result['name']);
            $oauth_email = $result['email'];

            if (isset($oauth_userid) && isset($oauth_username) && isset($oauth_email)) {
                $google_auth = Oauth::where('oauth_userid', '=', $oauth_userid)->where('service', '=', 'google')->first();

                if (isset($google_auth->id)) {
                    $user = $this->user->find($google_auth->user_id);
                } else {
                    // Execute Add or Login Oauth User
                    $user = $this->user->where('email', '=', $oauth_email)->first();

                    if (!isset($user->id)) {
                        $username = $this->createUsernameIfExists($oauth_username);
                        $email = $oauth_email;
                        $password = Hash::make(Helper::slugify('', 12));
                        $user = $this->newUser($username, $email, $password, 1, null);
                        $new_oauth_user = new Oauth();
                        $new_oauth_user->user_id = $user->id;
                        $new_oauth_user->service = 'google';
                        $new_oauth_user->oauth_userid = $oauth_userid;
                        $new_oauth_user->save();
                    } else {
                        // Redirect and send error message that email already exists. Let them know that they can request to reset password if they do not remember
                        return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.oauth_email_used'), 'toastType' => 'showErrorToast'));
                    }
                }
                // Redirect to new User Login;
                Auth::login($user, true);
                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.google_success'), 'toastType' => 'showSuccessToast'));
            
            }
        } else {
            // get googleService authorization
            $url = $googleService->getAuthorizationUri();

            return Redirect::to((string)$url);
        }
    }

    public function signup()
    {
        $validation = Validator::make(Input::all(), static::$rules);
        if ($validation->fails()) {
            $message = $validation->messages()->all()[0];
            return Redirect::to('/')->with(array('toastMsg' => $message, 'toastType' => 'showErrorToast'));
        }
        $username = htmlspecialchars(stripslashes(Input::get('username')));
        $user = $this->user->where('username', '=', $username)->first();
        if (!$user) {
            $settings = Setting::first();
            if (count(explode(' ', $username)) == 1) {
                if (Input::get('password') != '') {
                    $email = Input::get('email');
                    $activation_code = str_random(64);
                    $user = $this->newUser($username, $email, Hash::make(Input::get('password')), 0, $activation_code);
                    $data = array('username' => $username, 'activation_code' => $activation_code);
                    Mail::send(
                        'emails.welcome',
                        $data,
                        function ($message) use ($email) {
                            $message->to($email)->subject(Lang::get('words.activation_subject'));
                        }
                    );
                    return Redirect::to('/')->with(array('toastMsg' =>Lang::get('words.signup_success'), 'toastType' => 'showSuccessToast'));
                } else {
                    return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.signup_invalidpass'), 'toastType' => 'showErrorToast'));
                }
            } else {
                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.username_no_spaces'), 'toastType' => 'showErrorToast'));
            }
        } else {
            return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.username_in_use'), 'toastType' => 'showErrorToast'));
        }
    }

    // *********** CREATE A NEW USERNAME WITH USERNAME EMAIL AND PASSWORD ********** //

    private function newUser($username, $email, $password, $active = 0, $activation_code = null)
    {
        $user = new User();
        $user->username = $username;
        $user->email = $email;
        $user->password = $password;
        $user->active = $active;
        $user->activation_code = $activation_code;
        $user->save();
        return $user;
    }

    // *********** LOOP THROUGH USERNAMES TO RETURN ONE THAT DOESN'T EXIST ********** //

    private function createUsernameIfExists($username)
    {
        $user = $this->user->where('username', '=', $username)->first();

        while (isset($user->id)) {
            $username = $username.Helper::slugify('', 4);
            $user = $this->user->where('username', '=', $username)->first();
        }

        return $username;
    }

    // *********** UPDATE USER ********** //

    public function update($id)
    {
        $input = array_except(Input::all(), '_method');
        $validation = Validator::make($input, User::$update_rules);
        $redirect = $input['redirect'];

        if ($validation->passes()) {
            $user = $this->user->find($id);

            if ($input['password'] == '') {
                $input['password'] = $user->password;
            } else {
                $input['password'] = Hash::make($input['password']);
            }

            $user->update($input);

            return Redirect::to($redirect)->with(array('toastMsg' => Lang::get('words.profile_updated'), 'toastType' => 'showSuccessToast'));
        }

        return Redirect::to($redirect)
            ->withInput()
            ->withErrors($validation)
            ->with(array('toastMsg' => Lang::get('words.validation_errors'), 'toastType' => 'showErrorToast'));
    }

    // *********** SHOW USER PROFILE ********** //

    public function profile()
    {
        $ads = Ads::first();
        $settings = Setting::first();
        $user = $this->user->where('id', '=', Auth::user()->id)->first();
        if ($user) {
            $data = array(
                    'user' => $user,
                    'ads' => $ads,
                    'settings' => $settings
                    );
            return View::make('user.index', $data);
        } else {
            return Redirect::to('404');
        }
    }

    // ********** RESET PASSWORD LINK ********** //

    public function recover()
    {
        $code = Input::get('code');
        $user = $this->user->where('activation_code', '=', $code)->where('active', '=', 1)->first();

        if ($user) {
            return View::make('auth.reset-password-form', array('user' => $user));
        } else {
            return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.reset_link_expired'), 'toastType' => 'showErrorToast'));
        }
    }

    // ********** RESET PASSWORD SEND MAIL ********** //

    public function forgotPassword()
    {
        $email = Input::get('email');
        $user = $this->user->where('email', '=', $email)->where('active', '=', 1)->first();

        if ($user) {
            $reset_code = str_random(64);
            $user->activation_code = $reset_code;
            if ($user->save()) {
                $data = array('username' => $user->username, 'reset_code' => $reset_code);
                Mail::send(
                    'emails.forgot-password',
                    $data,
                    function ($message) use ($email) {
                        $message->to($email)->subject(Lang::get('words.reset_password'));
                    }
                );

                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.reset_link_sent').' '.$email, 'toastType' => 'showSuccessToast'));
            }
        } else {
            return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.user_not_found').' '.$email, 'toastType' => 'showErrorToast'));
        }
    }

    // ********** RESET PASSWORD LINK ********** //

    public function reset($token)
    {
        $user = $this->user->where('activation_code', '=', $token)->where('active', '=', 1)->first();
        if ($user) {
            $input = array_except(Input::all(), '_method');
            $validation = Validator::make($input, User::$update_rules);

            if ($validation->passes()) {
                if (!empty($input['password'])) {
                    $user->password = Hash::make($input['password']);
                    $user->activation_code = null;
                    $user->save();

                    return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.password_reset'), 'toastType' => 'showSuccessToast'));
                }
            } else {
                return Redirect::to('/')
                    ->withInput()
                    ->withErrors($validation)
                    ->with(array('toastMsg' => Lang::get('words.validation_errors'), 'toastType' => 'showErrorToast'));
            }
        }
    }

    // ********** Activate User if email is confirmed ********** //

    public function activation()
    {
        $code = Input::get('code');

        if ($code) {
            $user = $this->user->where('activation_code', '=', $code)->where('active', '=', 0)->first();

            if ($user) {
                $user->activation_code = null;
                $user->active = 1;
                $user->save();

                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.email_verified'), 'toastType' => 'showSuccessToast'));
            } else {
                return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.email_already_activated'), 'toastType' => 'showErrorToast'));
            }
        }
    }
}
