<?php

use Illuminate\Auth\UserTrait;
use Illuminate\Auth\UserInterface;
use Illuminate\Auth\Reminders\RemindableTrait;
use Illuminate\Auth\Reminders\RemindableInterface;

class User extends Eloquent implements UserInterface, RemindableInterface
{
    use UserTrait, RemindableTrait;

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'users';

    protected $fillable = array('username', 'email', 'password');

    public static $update_rules = array(
        'email' => 'required|email',
        'password' => 'alpha_dash|between:6,12|confirmed',
        'password_confirmation' => 'alpha_dash|between:6,12',
    );

    public function getFbID()
    {
        return DB::table('oauth_facebook')->where('user_id', '=', $this->id)->first()->oauth_userid;
    }

    /**
     * The attributes excluded from the model's JSON form.
     *
     * @var array
     */
    protected $hidden = array('password');

    /**
     * Get the unique identifier for the user.
     *
     * @return mixed
     */
    public function getAuthIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Get the password for the user.
     *
     * @return string
     */
    public function getAuthPassword()
    {
        return $this->password;
    }

    /**
     * Get the e-mail address where password reminders are sent.
     *
     * @return string
     */
    public function getReminderEmail()
    {
        return $this->email;
    }

    public function totalTracks()
    {
        return DB::table('playlist')->where('user_id', '=', $this->id)->count();
    }
}
