<?php

Route::when('*', 'csrf', array('post'));

// **********   INDEX ROUTE *********//
Route::get('/', 'IndexController@index');
Route::get('update', 'IndexController@update');

// **********   INSTALL ROUTES *********//
Route::get('install', 'IndexController@install');
Route::post('write-db-config-file', 'IndexController@writeDBConfigFile');
Route::post('is-db-connect', 'IndexController@isDBConnect');
Route::post('create-db', 'IndexController@createDB');
Route::post('create-admin', 'IndexController@createAdmin');

// LOGIN
Route::post('login', 'UserController@login');

// SIGNUP
Route::post('signup', 'UserController@signup');

// SIGN UP BY EMAIL
Route::post('emailsignup', 'UserController@emailSignup');

// SEND EMAIL ACTIVATION LINK
Route::get('activation', 'UserController@activation');

// FORGOT PASSWORD
Route::post('forgot-password', 'UserController@forgotPassword');

// RESET PASSWORD LINK
Route::get('recover', 'UserController@recover');
Route::post('reset/{token}', 'UserController@reset');
// LOGOUT
Route::get(
    'logout',
    function () {
        Auth::logout();
        return Redirect::to('/')->with(array('toastMsg' => Lang::get('words.logged_out'), 'toastType' => 'showSuccessToast'));
    }
);

// OAUTH ROUTES
Route::get('auth/facebook', 'UserController@loginWithFacebook');
Route::get('auth/twitter', 'UserController@loginWithTwitter');
Route::get('auth/google', 'UserController@loginWithGoogle');

// **********   Download ROUTES  ********** //
Route::get('download/{title}/{trackID}', 'SoundCloudController@download');

// **********   USER LOGGED IN ROUTES  ********** //
Route::group(
    array('before' => 'auth'),
    function () {

        /**********   USER PROFILE ROUTES   **********/
        Route::get('profile', 'UserController@profile');

        /**********   Playlist ROUTES  **********/
        Route::get('playlist', 'PlaylistController@index');
        Route::get('playlist-ajax', 'PlaylistController@getPlaylistLi');
        Route::post('playlist/add_track', 'PlaylistController@addTrack');

        /********** User Routes **********/
        Route::get('user/{username}/edit', 'UserController@edit');
        Route::post('user/update/{id}', 'UserController@update');

    }
);

// **********   ADMIN ROUTES  ********** //
Route::group(
    array('before' => 'admin'),
    function () {
        Route::get('admin', 'AdminController@index');
        Route::get('admin/home', 'AdminController@home');
        Route::get('admin/users', 'AdminController@users');
        Route::get('admin/settings', 'AdminController@settings');
        Route::get('admin/social', 'AdminController@social');
        Route::get('admin/playlist/{id}', 'PlaylistController@index');
        Route::get('admin/adcode', 'AdminController@ads');
        Route::post('admin/update_home', 'AdminController@updateHome');
        Route::post('admin/update_adcode', 'AdminController@updateAds');
        Route::post('admin/update_settings', 'AdminController@updateSettings');
        Route::post('admin/update_social', 'AdminController@updateSocial');
        Route::get('admin/deactivate_user/{id}', 'AdminController@deactivateUser');
        Route::get('admin/activate_user/{id}', 'AdminController@activateUser');
        Route::get('admin/pages', 'AdminController@pages');
        Route::post('admin/pages', 'AdminController@updatePages');
        Route::post('admin/genres', 'AdminController@toggleGenre');
    }
);

// **********   Ads ROUTES  ********** //
Route::get('ads/{type}', 'AdsController@show');

// **********   SEARCH ROUTES  ********** //
Route::get('search/{search}', 'SoundCloudController@search');

// ********* POPULAR ROUTE ********** //
Route::get('/{category}', 'AppleAPIController@getSongs');

// ********* PAGES ******** //
Route::get('page/{title}', 'PageController@show');

// ******** 404 ******** //
Route::get(
    '404',
    function () {
        return View::make('errors.index');
    }
);
